Package: fluxible
Title: Ecosystem Gas Fluxes Calculations for Closed Loop Chamber Setup
Version: 1.4.0
Date: 2026-07-22
Authors@R: 
    c(person(given = "Joseph", family = "Gaudard", , "joseph.gaudard@pm.me", role = c("aut", "cre"),
            comment = c(ORCID = "0000-0002-6989-7624")),
    person(given = c("Richard", "James"), family = "Telford", , "richard.telford@uib.no", role = "aut",
            comment = c(ORCID = "0000-0001-9826-3076"))
    )
Description: Toolbox to process raw data from closed loop flux chamber (or tent)
    setups into ecosystem gas fluxes usable for analysis. It goes from a
    data frame of gas concentration over time (which can contain several
    measurements) and a meta data file indicating which measurement was done
    when, to a data frame of ecosystem gas fluxes including quality diagnostics.
    Organized with one function per step, maximizing user flexibility and backwards
    compatibility. Different models to estimate the fluxes from the raw data are
    available: exponential as described in
    Zhao et al (2018) <doi:10.1016/j.agrformet.2018.08.022>, exponential as described in
    Hutchinson and Mosier (1981) <doi:10.2136/sssaj1981.03615995004500020017x>,
    quadratic, and linear. Other functions include quality assessment,
    plotting for visual check, calculation of fluxes based on the setup
    specific parameters (chamber size, plot area, ...), gross primary production
    and transpiration rate calculation, and light response curves.
License: GPL (>= 3)
Encoding: UTF-8
Suggests: knitr, rmarkdown, testthat (>= 3.0.0), vdiffr, tidyverse, fs,
        licoread, readr
Config/testthat/edition: 3
Imports: broom, dplyr (>= 1.0.10), ggforce, ggplot2, haven, lubridate,
        rlang (>= 0.4.0), purrr, stats, stringr, tidyr, zoo, progress,
        purrrlyr, tidyselect, lifecycle, forcats, tibble
Depends: R (>= 4.1)
LazyData: true
URL: https://plant-functional-trait-course.github.io/fluxible/,
        https://github.com/Plant-Functional-Trait-Course/fluxible
VignetteBuilder: knitr
BugReports: https://github.com/Plant-Functional-Trait-Course/fluxible/issues
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-22 14:59:22 UTC; jga051
Author: Joseph Gaudard [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-6989-7624>),
  Richard James Telford [aut] (ORCID:
    <https://orcid.org/0000-0001-9826-3076>)
Maintainer: Joseph Gaudard <joseph.gaudard@pm.me>
Repository: CRAN
Date/Publication: 2026-07-22 15:30:02 UTC
Built: R 4.5.2; ; 2026-07-22 16:45:47 UTC; unix
