# Generated by roxygen2: do not edit by hand

export(flux_calc)
export(flux_conc)
export(flux_diff)
export(flux_drygas)
export(flux_fitting)
export(flux_flag_count)
export(flux_gpp)
export(flux_lrc)
export(flux_match)
export(flux_plot)
export(flux_quality)
export(flux_units)
export(stupeflux)
importFrom(broom,glance)
importFrom(broom,tidy)
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,case_when)
importFrom(dplyr,coalesce)
importFrom(dplyr,cross_join)
importFrom(dplyr,cur_group_id)
importFrom(dplyr,desc)
importFrom(dplyr,distinct)
importFrom(dplyr,enquo)
importFrom(dplyr,everything)
importFrom(dplyr,filter)
importFrom(dplyr,full_join)
importFrom(dplyr,group_by)
importFrom(dplyr,group_by_at)
importFrom(dplyr,join_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n_distinct)
importFrom(dplyr,nest_by)
importFrom(dplyr,pull)
importFrom(dplyr,rename)
importFrom(dplyr,rename_with)
importFrom(dplyr,right_join)
importFrom(dplyr,row_number)
importFrom(dplyr,rowwise)
importFrom(dplyr,select)
importFrom(dplyr,slice)
importFrom(dplyr,summarise)
importFrom(dplyr,summarize)
importFrom(dplyr,tibble)
importFrom(dplyr,ungroup)
importFrom(dplyr,vars)
importFrom(forcats,fct_reorder)
importFrom(ggforce,facet_wrap_paginate)
importFrom(ggplot2,aes)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggsave)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_linetype_manual)
importFrom(ggplot2,scale_x_datetime)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,ylim)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(haven,as_factor)
importFrom(lifecycle,deprecate_warn)
importFrom(lifecycle,deprecated)
importFrom(lifecycle,is_present)
importFrom(lubridate,int_length)
importFrom(lubridate,interval)
importFrom(lubridate,is.POSIXct)
importFrom(progress,progress_bar)
importFrom(purrr,map)
importFrom(purrr,possibly)
importFrom(purrr,quietly)
importFrom(purrrlyr,slice_rows)
importFrom(purrrlyr,unslice)
importFrom(rlang,"!!")
importFrom(rlang,":=")
importFrom(rlang,.data)
importFrom(rlang,abort)
importFrom(rlang,as_label)
importFrom(rlang,as_name)
importFrom(rlang,enquo)
importFrom(rlang,get_expr)
importFrom(rlang,quo_is_missing)
importFrom(rlang,quo_is_symbol)
importFrom(rlang,quo_is_symbolic)
importFrom(stats,cor)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,nls)
importFrom(stats,nls.control)
importFrom(stats,optim)
importFrom(stringr,str_c)
importFrom(stringr,str_detect)
importFrom(stringr,str_extract)
importFrom(tibble,rowid_to_column)
importFrom(tidyr,drop_na)
importFrom(tidyr,fill)
importFrom(tidyr,nest)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,pivot_wider)
importFrom(tidyr,replace_na)
importFrom(tidyr,unite)
importFrom(tidyr,unnest)
importFrom(tidyselect,any_of)
importFrom(utils,data)
importFrom(zoo,rollmean)
